@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: text-icu
 version: 0.7.0.1
-id: text-icu-0.7.0.1-6e6eefd2e8d16edc12cf2661f6f4ef14
-key: texti_BDNnVMyFWVkKtdcdAjojGW
+id: text-icu-0.7.0.1-5ca732f0eac6589810e9e4239ad6c2ab
+key: texti_8oLA8kQX1CN1ro6YBp6YQE
 license: BSD3
 copyright: 2009-2014 Bryan O'\''Sullivan
 maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
@@ -51,14 +51,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/text-icu-0.7.0.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/text-icu-0.7.0.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/text-icu-0.7.0.1
-hs-libraries: HStext-icu-0.7.0.1-BDNnVMyFWVkKtdcdAjojGW
+hs-libraries: HStext-icu-0.7.0.1-8oLA8kQX1CN1ro6YBp6YQE
 extra-libraries:
     icuuc icui18n icudata
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
 haddock-interfaces: /usr/share/doc/haskell-text-icu/html/text-icu.haddock
 haddock-html: /usr/share/doc/haskell-text-icu/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
